pub fn add_server(
server_name: &str,
address: &str,
port: i32,
password: &str,
) -> Result<()>Expand description
Register a server to which the client will try to connect.
This should be called when server discovery is not enabled or the server is not discoverable.